import datetime
import BroadcastCalendar.brodacastcalendar.broadcast_calendar as bc
import math


def get_broadcast_details_range_from_year_week_and_week_count(
        start_year, start_week, num_of_weeks):

    start_date = bc.get_broadcast_week_start_from_year_and_week(start_year,
                                                                start_week)

    if num_of_weeks < 0:
        date_range = [
            start_date - datetime.timedelta(weeks=x)
            for x in range(0, abs(num_of_weeks))
        ]
    else:
        date_range = [
            start_date + datetime.timedelta(weeks=x)
            for x in range(0, abs(num_of_weeks))
        ]

    for x in date_range:
        yield bc.get_broadcast_details(x)


def get_broadcast_details_range_from_date_and_week_count(start_date,
                                                         week_count):

    start_date = bc.get_broadcast_week_start(start_date)

    if week_count < 0:
        date_range = [
            start_date - datetime.timedelta(weeks=x)
            for x in range(0, abs(week_count))
        ]
    else:
        date_range = [
            start_date + datetime.timedelta(weeks=x)
            for x in range(0, abs(week_count))
        ]

    for x in date_range:
        yield bc.get_broadcast_details(x)


def get_broadcast_details_range(start_date, end_date, inclusive=False):
    """
    returns a generator over a weekly date range for broadcast details 
    (year, week, quarter) optionally allows for an inclusive range
    :param start_date: date within the broadcast week to start range
    :param end_date: date within the broadcast week to stop range
    :param inclusive: flag to include the end_date week
    :return: generator of broadcast details
    """
    start_date = bc.get_broadcast_week_start(start_date)
    end_date = bc.get_broadcast_week_start(end_date)

    weeks_between = abs(math.floor((end_date - start_date).days / 7))

    if inclusive:
        weeks_between += 1

    return get_broadcast_details_range_from_date_and_week_count(
        start_date, weeks_between)
